/* @(#) acl.h 1.36 7/26/95 18:23:27 */

/* Copyright Star Gate Technologies 1989-1995 */


/*****************************************************************************/
/*
/*	TRACE FUNCTIONS + CONTROLS...
/*
/*****************************************************************************/

#ifdef TRACE			/* Tracing included */

#define TEST_BOARD(board)					\
	if (board != acl_on_board) {				\
		printf("ACL ERR: Line=%d board=%d sel=%d\n",	\
			__LINE__, board, acl_on_board);		\
		ON_BOARD(board);				\
	}

#ifdef STRINGIZE
#define TRACE_MSG(class, proc, msg)				\
	if (((class)&acl_trc_class)&&(proc&acl_trc_proc))	\
		printf("ACL " #proc " (" #class "): " #msg "\n");

#define TRACE_VAL(class, proc, val)					\
	if (((class)&acl_trc_class)&&(proc&acl_trc_proc))		\
	printf("ACL "#proc " ("#class "): "#val "=\t%o(o),\t%d(d),\t%x(x)\n",\
		 (val), (val), (val));

#else
#define TRACE_MSG(class, proc, msg)				\
	if (((class)&acl_trc_class)&&(proc&acl_trc_proc))	\
		printf("ACL proc (class): msg\n");

#define TRACE_VAL(class, proc, val)					\
	if (((class)&acl_trc_class)&&(proc&acl_trc_proc))		\
	  printf("ACL proc (class): val=\t%o(o),\t%d(d),\t%x(x)\n",	\
		 (val), (val), (val));
#endif

extern int acl_trc_class;	/* trace class (1 bit/class)	*/
extern int acl_trc_proc ;	/* trace proc  (1 bit/proc)	*/

#else				/* Tracing NOT included */
#define TEST_BOARD(board)					\
	if (board != acl_on_board) 				\
		ON_BOARD(board);
#define TRACE_MSG(class, proc, msg)
#define TRACE_VAL(class, proc, val)
#endif

/*****************************************************************************/
/*
/*	CONSTANTS
/*
/*****************************************************************************/

/* Size of vector to board num map... */
#define VTOB_SIZE 32

/* Bus types ... */
#define ACL_AT_BUS	0x01
#define ACL_MC_BUS	0x02

/*
 * Mode of operation (acl_mode) ...
 */
#define INTERRUPT	0x01
#define POLL_REQUESTED	0x02
#define POLL_STARTED	0x04

/*
 * Board id's ...
 */
#define ACL_ACL16ID	0xa1
#define ACL_ACL16PLID	0xa2
#define ACL_ACLMCID	0x67e1
#define ACL_ACLMCPID	0x61a0
#define ACL_ACLMC3AID	0x6406
#define ACL_ACLMC3BID	0x6408
#define ACL_A100MID	0x621c
#define ACL_A101MID	0x6407
#define ACL_A201MID	0x637b
#define ACL_A100EID0	0x4C
#define ACL_A100EID1	0xF4
#define ACL_A100EID2	0x01
#define ACL_A100EID3	0x01
#define ACL_A116IID	0x13EC
#define ACL_A140IID	0x6996

/*
 * h/w constants
 */
#define ACLMCP_ENABLE	0x01
#define ACLMCP_RUN	0x02
#define ACLMCP_8K	0x04
#define ACLMCP_WIN1	0x08
#define ACLMCP_IRQMASK	0xF0
#define ACLMCP_IRQLEV	0x70
#define ACLMCP_IRQEN	0x80

#define A100E_FCR	0xCAE
#define A100E_MEMEN	0x10

#define A100E_OPR	(-1)
#define A100E_RUN	0x01
#define A100E_BANK	0x02

#define A100E_IPR	(-2)
#define A100E_READY	0x01

#define A100E_ICR0	(-5)
#define A100E_IRQBITS	0x03
#define A100E_IRQEN	0x08

#define A100E_DSR	(-6)
#define A100E_INTSEL	0x01

#define A100E_MCR1	(-13)
#define A100E_16BIT	0x4E
#define A100E_32BIT	0x6E

#define A100E_BCR	(0x0C84-0x0CAE)
#define A100E_ENABLE	0x01
#define A100E_RESET	0x04

#define A100I_CR1	1
#define A100I_READY	0x01
#define A100I_NORMAL	0x02
#define A100I_IRQEN	0x80
#define A100I_CR2	2
#define A100I_BANKSEL	0x03
#define A100I_MEMEN	0x10
#define A100I_MEMEN_MASK	0x10

/*
 * Priority constants...
 */
#define splACL() (acl_mode & POLL_REQUESTED ? spl7() : spl5())
#define ACLPRI PZERO+5

/*****************************************************************************/
/*
/*	DATA STRUCTURES
/*
/*****************************************************************************/

/*
 * dual port memory structures
 */

struct channel_control_block {	 /* per port control block */

  ushort baud_rate      ; /* baud rate */
  ushort data_format    ; /* LoopModes:Stick:Even:Parity:Stop:CharSize */
  ushort line_protocol  ; /* IXON:IXANY:IXOFF:CTS controls xmit:	 */
			  /* rcvr controls RTS: xmit controls RTS: */
			  /* in_buf controls RTS: MODEM: DCE	 */

  ushort in_buf_size    ; /* input buffer size */
  ushort out_buf_size   ; /* output buffer size */
  ushort int_rate;	  /* min chars for rx int without timeout */
  ushort out_buf_lowat  ; /* output low water mark */
  ushort xon_xoff_char  ; /* ms = xon, ls = xoff */
  ushort in_buf_hiwat   ; /* in buf high water mark */
  ushort in_buf_lowat   ; /* in buf low water mark */
  ushort config_command ; /* See config commands below. */

  ushort config_status  ; /* 0=no err,1=baud,2=data_format,3=line_protcol,
                             4=isize,5=osize,6=irate,7=olow,8=xon/xof
                             9=ihi,a=ilow,b=bad uart */

  ushort in_buf_start   ; /* input buffer start address */
  ushort in_buf_end     ; /* input buffer ending address */
  ushort out_buf_start  ; /* output buffer start address */
  ushort out_buf_end    ; /* output buffer start address */
  ushort in_buf_to      ; /* next char to input buffer address */
  ushort in_buf_from    ; /* next char from input buffer address */
  ushort out_buf_to     ; /* next char to output buffer address */
  ushort out_buf_from   ; /* next char from output buffer address */
  ushort comm_status    ; /* 1=oe, 2=pe, 4=fe,8=break */
  ushort bad_char_offset; /* addr of char with rx err */
  ushort modem_control  ; /* See modem controls below */
  ushort modem_status   ; /* See modem status below */
  ushort blocking_status; /* 00000000 00:RTS low:XOFF sent:   */
			  /* CTS low Tx Block:XOFF Tx Block:  */
			  /* Tx dis:Rx dis		    */

  ushort char_rx_flag   ; /* set to 0xffff on each char received */
  ushort ixoff_char  	; /* ms = xon, ls = xoff */
  ushort chan_status  	; /* aux buf not empty */
};

/*
 * Dual port as the prom code views it...
 */
#define PROM_STAT(dp)	dp->command
#define PROM_CMD(dp)	 dp->status
#define PROM_RSP(dp)	 dp->i_all
#define MEM_CHECK(dp)	 dp->cp_version

/*
 * line_protocol bits...
 */
#define LP_CTSCT	0x0008	/* enable CTS control of Tx */
#define LP_RCRTS	0x0010	/* enable Rx control of RTS */
#define LP_IBRTS	0x0040	/* enable in buf control of RTS */
#define LP_MODEM	0x0080	/* enable modem control/status */
#define LP_DCE		0x0100	/* enable operation as a dce */
#define LP_RS422	0x2000	/* enable operation as a RS422 */

/*
 * config_commands...
 */
#define CC_DIS_TX   0x0080 /* config_status: disable transmitter */
#define CC_ENA_TX   0x0040 /* enable transmitter */
#define CC_DIS_RX   0x0020 /* disable receiver */
#define CC_ENA_RX   0x0010 /* enable receiver */
#define CC_FLUSH_TX 0x0008 /* flush transmitter */
#define CC_FLUSH_RX 0x0004 /* flush receiver */
#define CC_PORT     0x0002 /* logical config */
#define CC_UART     0x0001 /* logical and physical config */

/*
 * received charater errors...
 */
#define RE_BREAK	0x0008 /* break received */
#define RE_FRAME	0x0004 /* framing error */
#define RE_PARITY	0x0002 /* parity error */
#define RE_ORUN		0x0001 /* overrun error */

/*
 * modem_controls...
 */
#define MC_DTR          0x0001 /* set DTR */
#define MC_RTS          0x0002 /* set RTS */
#define MC_BREAK        0x0010 /* send Break */

/*
 * modem_status...
 */
#define MS_CTS          0x0001 /* CTS input */
#define MS_DSR          0x0002 /* DSR input */
#define MS_RI           0x0004 /* RI input */
#define MS_DCD          0x0008 /* DCD input */

/*
 * chan_status...
 */
#define CS_XBUF_NE	0x0001 /* aux buf not empty */


struct global_control_block { 	/* per board control block */

  ushort command        ;/* command word */
  ushort status         ;/* status word */
  ushort i_all          ;/* channels with any interrupt */
  ushort available_space;/* available buffer space remiaining */
  ushort board_type     ;/* 0=acl board */
  ushort cp_version     ;/* 0x0400=version 4.00 */
  ushort nports         ;/* number of channels */
  ushort ccb_offset     ;/* offset in dp of 1st chan cb */
  ushort ccb_size       ;/* size of ccb's in bytes */
  ushort i_ack          ;/* bit 0 = interrupt ack */
  ushort status2        ;/* status word 2 */
  ushort i_err          ;/* channels with comm errors intr */
  ushort i_rcv          ;/* channels with input interrupt  */
  ushort i_out          ;/* channels with output interrupt */
  ushort i_modem        ;/* channels with modem status chg */
  ushort i_config       ;/* channels with config complete  */
};

/*
 * status2...
 */
#define GS2_CAN_232	0x0001 /* can do RS232 */
#define GS2_CAN_422	0x0002 /* can do RS422 */
#define GS2_CAN_MDM	0x0004 /* for modem panel */
#define GS2_HAS_RJS	0x0080 /* RJ12s (not DB25s) */
#define GS2_HAS_RI	0x0100
#define GS2_HAS_DCD	0x0200
#define GS2_HAS_DTR	0x0400
#define GS2_HAS_DSR	0x0800
#define GS2_HAS_CTS	0x1000
#define GS2_HAS_RTS	0x2000


/*
 * Internal Data Structures.
 */

struct port_info {	/* one per port */

  ccb_t p_ccb;	/* kernel virtual of ccb */
  ushort p_state;			/* see below */
  ushort p_irate;			/* input interrupt rate */
  ushort p_cbaud;			/* current cbaud */
  struct ttp_info p_ttp;		/* ttp config info */
  int p_dev;				/* minor device # */
  unsigned short x_hflag;		/* hardware flow control modes */
#ifdef VPIX
#ifndef FOR_286
  v86_t * v86p;		/* vpix - proc.p_v86 for pseudo interrupts */
#endif
  ushort intmask;	/* vpix - which pseudo interrupt to give */
  ushort ms_8250;	/* vpix - 8250 modem status read emulation */
  ushort divisor;	/* vpix - tracking ms/ls divisor latch */
#endif
};

/*
 * port states:
 */
#define PORT_INITED	0x01
#define TTP_INITED	0x02
#define WAIT_CONFIG	0x04
#define OPEN_AS_DCE	0x08
#define OPEN_AS_422	0x10
#define ACL_PS_TTYB	0x80 /* normal tty-port has non-empty clist (CPRES) */
				/* so temporarily block ttp-port output */
