/* @(#) aclioctl.h 1.26 11/4/94 14:53:52 */

/*
 * I/O definitions for the acl.
 */

#ifndef faddr_t
#define faddr_t caddr_t
#endif

/*	How many boards for those who do ACLGETBDCFG... */
#ifndef NOTTPS
#define MAXBOARDS 4
#else
#define MAXBOARDS 8
#endif

/*	Trace constants for those support applications... */
/*
 * trace_class values:
 */
#define ENTRY	0x0001
#define XCEPT	0x0002
#define INFO	0x0004
#define LINE	0x0008

/*
 * trace_proc values:
 */
#define INIT	0x0001
#define OPEN	0x0002
#define CLOSE	0x0004
#define READ	0x0008
#define WRITE	0x0010
#define IOCTL	0x0020
#define INTR	0x0040
#define PROC	0x0080

#define RESET	0x0100
#define PARAM	0x0200
#define CONFIG	0x0400
#define OUTPUT	0x0800
#define INPUT	0x1000
#define MODEM	0x2000
#define POLLTTP	0x4000

/*
 * Ioctl cmds for the board level functions...
 *
 * Upper 8 bits = 'A', Lower 8 bits = cmd number
 */

#define AIO(x) (('A'<< 8)|(x))

/* Port data structure access for configuration and debug... */
#define ACLGETTTY	AIO(0x21)
#define ACLGETTTP	AIO(0x22)
#define ACLSETTTP	AIO(0x23)
#define ACLSETIRATE	AIO(0x24)
#define ACLSET232	AIO(0x25)
#define ACLSET422	AIO(0x26)
#define ACLGETEIA	AIO(0x27)

/* Trace level control... */
#define ACLGETCLASS	AIO(0x11)
#define ACLSETCLASS	AIO(0x12)
#define ACLGETPROC	AIO(0x13)
#define ACLSETPROC	AIO(0x14)

/* Board control... */
#define ACLBOARDSEL	AIO(0x01)
#define ACL16BLKSEL	AIO(0x02)
#define ACLINITLOAD	AIO(0x03)
#define ACLLOAD		AIO(0x04)
#define ACLSTART	AIO(0x05)
#define ACLGETBDCFG	AIO(0x06)
#define ACLSETNBDS	AIO(0x07)
#define ACLSETBDCFG	AIO(0x08)
#define ACLBLKLOAD	AIO(0x09)
#define ACL16LOAD	AIO(0x0A)
#define ACLSETMODE	AIO(0x0B)
#define ACLSETBUS	AIO(0x0C)
#define A100MBLKSEL	AIO(0x0D)
#define A100MLOAD	AIO(0x0E)
#define A100EBLKSEL	AIO(0x31)
#define A100ELOAD	AIO(0x32)
#define ACLMCPBLKSEL	AIO(0x33)
#define ACLMCPLOAD	AIO(0x34)
#define A100IBLKSEL	AIO(0x35)
#define A100ILOAD	AIO(0x36)

/*
 * Pointer types ...
 */
#ifdef FOR_286
#define ccb_t struct channel_control_block far *
#define gcb_t struct global_control_block far *
#define mreg_t ushort far *
#else
#define ccb_t struct channel_control_block *
#define gcb_t struct global_control_block *
#define mreg_t ushort *
#endif

/*
 * Shared data structure for download...
 */
struct board_info {	/* one per board, pad to 4 byte boundry for Xenix 286 */
  faddr_t b_name;	/* = BD_n_NAME  /* board's name (eg ACLII) */
  gcb_t   b_gcb;	/* kernel virtual of gcb */
  mreg_t  b_mreg;	/* kernel virtual of MC,MC16 mem mapped register */
  paddr_t b_dpaddr;	/* = BD_n_DPA *//* physical of dual port */
  ushort  b_dpsize;	/* = BD_n_DPS *//* dual port size */
  ushort  b_ioaddr;	/* = BD_n_IOA *//* io register base address */
  ushort  b_IRQ;		/* = BD_n_IRQ */
  ushort  b_type;	/* type as found in dp->board_type (see below) */
  ushort  b_attr;	/* attributes this board posseses  (see below) */
  ushort  b_nwaits;	/* number of wait states (for programable bds only) */
  ushort  b_slot;	/* slot where board resides (MCA only) */
  ushort  b_state;	/* see below */
  ushort  b_bmask;	/* supported baud rates mask */
  char    b_offbd;	/* value for i/o reg0 to turn off board) */
  char    b_latch1;	/* value for i/o reg0 (depends on board) */
};

/*
 * board types:
 *	(reminder: add new boards to driver/[os]/osdep.c & 
 *	 driver/[os]/[flavor].mk, if needed [currently only needed in scou32])
 */
#define ACL_ACL		0
#define ACL_ACL2	1
#define ACL_ACL2R	2
#define ACL_ACL2S	3
#define ACL_ACLMC	4
#define ACL_ACL16	5
#define ACL_A100M	6
#define ACL_ACL2PL	7
#define ACL_ACL2RPL	8
#define ACL_ACL16PL	9
#define ACL_A100E	10
#define ACL_ACLMCP	11
#define ACL_A100I	12
#define ACL_A101M	13

/*
 * board attributes:
 */
#define ACL_CAN_XMEM	0x01
#define ACL_CAN_DCE	0x02
#define ACL_CAN_DBL	0x04
#define ACL_CAN_422	0x08

/*
 * board states:
 */
#define BOARD_MISSING	0x01
#define BOARD_PRESENT	0x02
#define BOARD_RESET	0x04
#define BOARD_NEXTBLK	0x08
#define BOARD_LOADED	0x10
#define BOARD_STARTED	0x20
#define BOARD_LOAD_BITS	(BOARD_RESET|BOARD_LOADED|BOARD_STARTED|BOARD_NEXTBLK)
#define BOARD_INTR_ON	0x40
#define BOARD_POLL_ON	0x80
#define BOARD_ON_BITS	(BOARD_INTR_ON|BOARD_POLL_ON)

/*
 * baud rate masks:
 */
#define BMASK_0			0x0001
#define BMASK_57600		0x0002		/* 50 */
#define BMASK_76800		0x0004		/* 75 */
#define BMASK_110		0x0008
#define BMASK_115200		0x0010		/* 134.5 */
#define BMASK_150		0x0020
#define BMASK_230400		0x0040		/* 200 */
#define BMASK_300_38400		0xFF80
#define BMASK_DEFAULT		BMASK_0|BMASK_110|BMASK_150|BMASK_300_38400

/*
 * Shared ttp constants and data structures...
 */
#define TTP_POLL_RATE	10	/* Poll frequency in hz */
#define TTP_TX_PERIOD	5	/* transmision period in poll times */
#define TTP_STR_SIZE	4	/* maximum on/off string size */

struct ttp_string {
	ushort len;		/* Actual length */
	char s[TTP_STR_SIZE];	/* It */
};

struct ttp_info {
	struct ttp_string on;
	struct ttp_string off;
	ushort chunk_size;	/* No of bytes/tx (incl. on and off) */
	ushort dp_offset;	/* Offset of end of last tx. */
};

#ifndef RTSXOFF

#define NFF	5

/* hardware flow control modes */

#define RTSXOFF  0000001 /* Enable RTS hardware flow control on input */
#define CTSXON   0000002 /* Enable CTS hardware flow control on output */

struct termiox {
	unsigned short x_hflag;		/* hardware flow control modes */
	unsigned short x_cflag;		/* clock modes */
	unsigned short x_rflag[NFF];	/* reserved modes*/
	unsigned short x_sflag;		/* spare modes */
};

#ifdef XIOC
#undef XIOC
#endif

#define XIOC    ('X'<<8)
#define TCGETX  (XIOC|1)
#define TCSETX  (XIOC|2)
#define TCSETXW (XIOC|3)
#define TCSETXF (XIOC|4)

#endif
